@@ -1,9 +1,12 @@
-import { resourceDetailsPages, resourceListPages } from '../../public/components/resource-pages';
+import {
+  getResourceDetailsPages,
+  getResourceListPages,
+} from '../../public/components/resource-pages';
 import { isGroupVersionKind } from '../../public/module/k8s';
 
 describe('resourceDetailsPages', () => {
   it('contains a map of promises which resolve to every resource detail view component', (done) => {
-    resourceDetailsPages.forEach((promise, name) => {
+    getResourceDetailsPages().forEach((promise, name) => {
       expect(name.length > 0).toBe(true);
       expect(isGroupVersionKind(name)).toBe(true);
 
@@ -17,7 +20,7 @@ describe('resourceDetailsPages', () => {
 
 describe('resourceListPages', () => {
   it('contains map of promises which resolve to every resource list view component', (done) => {
-    resourceListPages.forEach((promise, name) => {
+    getResourceListPages().forEach((promise, name) => {
       expect(isGroupVersionKind(name) || name === 'ClusterServiceVersionResources').toBe(true);
 
       promise().then((Component) => {
