@@ -4,6 +4,7 @@ import { $, $$, browser, by, ExpectedConditions as until, element } from 'protra
 
 import * as yamlView from './yaml.view';
 import { appHost, testName, waitForNone } from '../protractor.conf';
+import { waitForCount } from '@console/shared/src/test-utils/utils';
 
 export const createYAMLButton = $('#yaml-create');
 export const createItemButton = $('#item-create');
@@ -23,7 +24,7 @@ export const isLoaded = () =>
     .wait(until.and(untilNoLoadersPresent, untilLoadingBoxLoaded))
     .then(() => browser.sleep(1000));
 export const resourceRowsPresent = () =>
-  browser.wait(until.presenceOf($('.co-m-resource-icon + a')), 10000);
+  browser.wait(until.presenceOf($('.co-m-resource-icon + a')), 20000);
 export const errorPage = $('[data-test-id="error-page"]');
 
 export const resourceRows = $$('[data-test-rows="resource-row"]');
@@ -51,7 +52,7 @@ export const clickTab = async (name: string) => {
 };
 
 export const labelsForRow = (name: string) => rowForName(name).$$('.co-m-label');
-export const textFilter = $('.co-m-pane__filter-bar-group--filter input');
+export const textFilter = $('[data-test-id="item-filter"]');
 export const actions = Object.freeze({
   labels: 'Edit Labels',
   annotations: 'Edit Annotations',
@@ -76,11 +77,18 @@ const actionOnKind = (action: string, kind: string) => {
 export const editHumanizedKind = (kind: string) => actionOnKind(actions.edit, kind);
 export const deleteHumanizedKind = (kind: string) => actionOnKind(actions.delete, kind);
 
-export const clickKebabAction = (resourceName: string, actionLabel: string) => {
-  return rowForName(resourceName)
-    .$('[data-test-id="kebab-button"]')
+export const clickCreateWithYAML = async () => {
+  await browser.wait(until.elementToBeClickable(createYAMLButton));
+  await createYAMLButton.click();
+};
+
+export const clickKebabAction = async (resourceName: string, actionLabel: string) => {
+  const kbBtn = await rowForName(resourceName).$('[data-test-id="kebab-button"]');
+  await browser.wait(until.elementToBeClickable(kbBtn));
+  await kbBtn
     .click()
     .then(() => browser.wait(until.elementToBeClickable(actionForLabel(actionLabel))))
+    .then(() => browser.wait(waitForCount($$('.pf-m-disabled'), 0)))
     .then(() => actionForLabel(actionLabel).click());
 };
 
@@ -92,6 +100,7 @@ export const editRow = (kind: string) => (name: string) =>
     await browser.wait(until.presenceOf(cancelBtn));
     const reloadBtnIsPresent = await reloadBtn.isPresent();
     if (reloadBtnIsPresent) {
+      await browser.wait(until.elementToBeClickable(reloadBtn));
       await reloadBtn.click();
     }
     await saveChangesBtn.click();
@@ -108,7 +117,7 @@ export const deleteRow = (kind: string) => (name: string) =>
         await $('input[placeholder="Enter name"]').sendKeys(name);
         break;
       default:
-        await browser.wait(until.presenceOf($('#confirm-action')));
+        await browser.wait(until.elementToBeClickable($('#confirm-action')));
         break;
     }
 
@@ -117,16 +126,14 @@ export const deleteRow = (kind: string) => (name: string) =>
     const kebabIsDisabled = until.not(
       until.elementToBeClickable(rowForName(name).$('.co-kebab__button')),
     );
-    const listIsEmpty = until.textToBePresentInElement($('.cos-status-box > .text-center'), 'No ');
+    const listIsEmpty = until.textToBePresentInElement($('.cos-status-box__title'), 'No ');
     const rowIsGone = until.not(until.presenceOf(rowForName(name).$('.co-kebab')));
     return browser.wait(until.or(kebabIsDisabled, until.or(listIsEmpty, rowIsGone)));
   });
 
-export const rowFilters = $$('.row-filter__box');
-export const rowFiltersPresent = () => browser.wait(until.presenceOf($('.row-filter__box')));
-export const rowFilterFor = (name: string) =>
-  rowFilters.filter((el) => el.getText().then((text) => text.includes(name))).first();
-export const activeRowFilters = $$('.row-filter__box--active');
+export const rowFiltersButton = $('[data-test-id="filter-dropdown-toggle"]');
+export const rowFiltersPresent = () => browser.wait(until.presenceOf(rowFiltersButton));
+export const rowFilterFor = (name: string) => $(`[data-test-row-filter="${name}"]`);
 
 export const statusMessageTitle = $('.cos-status-box__title');
 export const statusMessageDetail = $('.cos-status-box__detail');
@@ -148,9 +155,10 @@ export const visitResource = async (resource: string, name: string) => {
 };
 
 export const clickDetailsPageAction = async (actionID: string) => {
-  const action = actionForLabel(actionID);
   await browser.wait(until.presenceOf(actionsButton));
   await actionsButton.click();
+  await browser.wait(until.presenceOf(actionsDropdownMenu));
+  const action = actionForLabel(actionID);
   await browser.wait(until.elementToBeClickable(action));
   await action.click();
 };
