@@ -1,4 +1,3 @@
-import { ClonePVC } from './clone-workflow';
 import { DeleteSnapshot } from './delete-snapshot-workflow';
 import { K8sKind } from '@console/internal/module/k8s';
 import { KebabAction } from '@console/internal/components/utils';
@@ -9,7 +8,7 @@ import { VolumeSnapshotModel } from '../models';
 
 export const getKebabActionsForKind = (resourceKind: K8sKind): KebabAction[] => {
   if (resourceKind?.kind === PersistentVolumeClaimModel.kind) {
-    return [SnapshotPVC, ClonePVC];
+    return [SnapshotPVC];
   }
   if (resourceKind?.kind === VolumeSnapshotModel.kind) {
     return [RestorePVC, DeleteSnapshot];
