@@ -3,6 +3,8 @@ import * as _ from 'lodash';
 import { safeDump } from 'js-yaml';
 import { coFetchJSON } from '@console/internal/co-fetch';
 import { K8sResourceKind } from '@console/internal/module/k8s';
+import { RowFilter } from '@console/internal/components/filter-toolbar';
+import { toTitleCase } from '@console/shared';
 import {
   HelmRelease,
   HelmChart,
@@ -11,8 +13,8 @@ import {
   HelmActionType,
   HelmActionConfigType,
   HelmActionOrigins,
+  HelmChartEntries,
 } from './helm-types';
-import { RowFilter } from '@console/internal/components/filter-toolbar';
 
 export const HelmReleaseStatusLabels = {
   [HelmReleaseStatus.Deployed]: 'Deployed',
@@ -77,16 +79,71 @@ export const fetchHelmReleases = (
   return coFetchJSON(fetchString);
 };
 
-export const getChartURL = (helmChartData: HelmChartMetaData[], chartVersion: string): string => {
-  const chartData: HelmChartMetaData = _.find(helmChartData, (obj) => obj.version === chartVersion);
+export const getChartURL = (
+  helmChartData: HelmChartMetaData[],
+  chartVersion: string,
+  chartRepoName: string,
+): string => {
+  const chartData: HelmChartMetaData = _.find(
+    helmChartData,
+    (obj) => obj.version === chartVersion && obj.repoName === chartRepoName,
+  );
   return chartData?.urls[0];
 };
 
+export const getChartEntriesByName = (
+  chartEntries: HelmChartEntries,
+  chartName: string,
+  chartRepoName?: string,
+): HelmChartMetaData[] => {
+  if (chartName && chartRepoName) {
+    return (
+      chartEntries?.[`${chartName}--${chartRepoName}`]?.map((e) => ({
+        ...e,
+        repoName: chartRepoName,
+      })) ?? []
+    );
+  }
+  const entries = _.reduce(
+    chartEntries,
+    (acc, charts, key) => {
+      const repoName = key.split('--').pop();
+      charts.forEach((chart: HelmChartMetaData) => {
+        if (chart.name === chartName) {
+          acc.push({ ...chart, repoName });
+        }
+      });
+      return acc;
+    },
+    [],
+  );
+  return entries;
+};
+
+export const concatVersions = (
+  chartVersion: string,
+  appVersion: string,
+  chartRepoName?: string,
+): string => {
+  let title = chartVersion.split('--')[0];
+  if (appVersion) {
+    title += ` / App Version ${appVersion}`;
+  }
+  if (chartRepoName) {
+    title += ` (Provided by ${toTitleCase(chartRepoName)})`;
+  }
+  return title;
+};
+
 export const getChartVersions = (chartEntries: HelmChartMetaData[]) => {
   const chartVersions = _.reduce(
     chartEntries,
     (obj, chart) => {
-      obj[chart.version] = chart.version;
+      obj[`${chart.version}--${chart.repoName}`] = concatVersions(
+        chart.version,
+        chart.appVersion,
+        chart.repoName,
+      );
       return obj;
     },
     {},
@@ -121,17 +178,25 @@ export const getHelmActionConfig = (
   switch (helmAction) {
     case HelmActionType.Install:
       return {
+        type: HelmActionType.Install,
         title: 'Install Helm Chart',
-        subTitle: 'The helm chart will be installed using the YAML shown in the editor below.',
+        subTitle: {
+          form:
+            'The Helm chart can be installed by completing the form. Default values may be provided by the Helm chart authors.',
+          yaml: 'The Helm chart can be installed by manually entering YAML or JSON definitions.',
+        },
         helmReleaseApi: `/api/helm/chart?url=${chartURL}`,
         fetch: coFetchJSON.post,
         redirectURL: getOriginRedirectURL(HelmActionOrigins.topology, namespace, releaseName),
       };
     case HelmActionType.Upgrade:
       return {
+        type: HelmActionType.Upgrade,
         title: 'Upgrade Helm Release',
-        subTitle:
-          'Upgrade by selecting a new chart version or manually changing the YAML shown in the editor below.',
+        subTitle: {
+          form: 'Upgrade by selecting a new chart version or manually changing the form values.',
+          yaml: 'Upgrade by selecting a new chart version or manually changing YAML.',
+        },
         helmReleaseApi: `/api/helm/release?ns=${namespace}&name=${releaseName}`,
         fetch: coFetchJSON.put,
         redirectURL: getOriginRedirectURL(actionOrigin, namespace, releaseName),
@@ -139,6 +204,7 @@ export const getHelmActionConfig = (
 
     case HelmActionType.Rollback:
       return {
+        type: HelmActionType.Rollback,
         title: 'Rollback Helm Release',
         subTitle: ``,
         helmReleaseApi: `/api/helm/release/history?ns=${namespace}&name=${releaseName}`,
@@ -166,3 +232,8 @@ export const getChartValuesYAML = (chart: HelmChart): string => {
 
   return !_.isEmpty(chart?.values) ? safeDump(chart?.values) : '';
 };
+
+export const getChartReadme = (chart: HelmChart): string => {
+  const readmeFile = chart?.files?.find((file) => file.name === 'README.md');
+  return (readmeFile?.data && atob(readmeFile?.data)) ?? '';
+};
