@@ -61,23 +61,26 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample, builderImages }) =>
           !values.application.name &&
           values.application.selectedKey !== UNASSIGNED_KEY &&
           setFieldValue('application.name', `${gitRepoName}-app`);
-        setFieldValue('image.isRecommending', true);
-        const buildTools: BuildType[] = await gitService.detectBuildTypes();
-        setFieldValue('image.isRecommending', false);
-        const buildTool = buildTools.find(
-          ({ buildType: recommended }) => recommended && builderImages.hasOwnProperty(recommended),
-        );
-        if (buildTool && buildTool.buildType) {
-          setFieldValue('image.couldNotRecommend', false);
-          setFieldValue('image.recommended', buildTool.buildType);
-        } else {
-          setFieldValue('image.couldNotRecommend', true);
-          setFieldValue('image.recommended', '');
+        if (builderImages) {
+          setFieldValue('image.isRecommending', true);
+          const buildTools: BuildType[] = await gitService.detectBuildTypes();
+          setFieldValue('image.isRecommending', false);
+          const buildTool = buildTools.find(
+            ({ buildType: recommended }) =>
+              recommended && builderImages.hasOwnProperty(recommended),
+          );
+          if (buildTool && buildTool.buildType) {
+            setFieldValue('image.couldNotRecommend', false);
+            setFieldValue('image.recommended', buildTool.buildType);
+          } else {
+            setFieldValue('image.couldNotRecommend', true);
+            setFieldValue('image.recommended', '');
+          }
         }
       } else {
         setFieldValue('image.recommended', '');
         setFieldValue('image.couldNotRecommend', false);
-        setValidated(ValidatedOptions.error);
+        setValidated(ValidatedOptions.warning);
       }
     },
     [
@@ -151,8 +154,8 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample, builderImages }) =>
     if (validated === ValidatedOptions.success) {
       return 'Validated';
     }
-    if (validated === ValidatedOptions.error) {
-      return 'Git repository is not reachable.';
+    if (validated === ValidatedOptions.warning) {
+      return 'URL is valid but cannot be reached. If this is a private repository, enter a source secret in Advanced Git Options';
     }
     return '';
   };
@@ -172,7 +175,8 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample, builderImages }) =>
       return;
     }
     !nameTouched && setFieldValue('name', '');
-    values.application.selectedKey !== UNASSIGNED_KEY &&
+    !values.application.isInContext &&
+      values.application.selectedKey !== UNASSIGNED_KEY &&
       !applicationNameTouched &&
       setFieldValue('application.name', '');
   };
@@ -196,6 +200,7 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample, builderImages }) =>
         data-test-id="git-form-input-url"
         required
       />
+      {sampleRepo && <SampleRepo onClick={fillSample} />}
       {values.git.showGitType && (
         <>
           <DropdownField
@@ -208,12 +213,11 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample, builderImages }) =>
           />
           {!gitTypeTouched && values.git.type === GitTypes.unsure && (
             <Alert isInline variant="info" title="Defaulting Git Type to Other">
-              We failed to detect the git type.
+              We failed to detect the Git type.
             </Alert>
           )}
         </>
       )}
-      {sampleRepo && <SampleRepo onClick={fillSample} />}
       <AdvancedGitOptions />
     </FormSection>
   );
