@@ -11,10 +11,11 @@ import {
   ValidatedOptions,
 } from '@patternfly/react-core';
 import { SecretTypeAbstraction } from '@console/internal/components/secrets/create-secret';
-import { InputField, useDebounceCallback } from '@console/shared';
+import { InputField, useDebounceCallback, CheckboxField } from '@console/shared';
 import { getSuggestedName, getPorts, makePortName } from '../../../utils/imagestream-utils';
 import { secretModalLauncher } from '../CreateSecretModal';
 import { UNASSIGNED_KEY, CREATE_APPLICATION_KEY } from '../../../const';
+import './ImageSearch.scss';
 
 const ImageSearch: React.FC = () => {
   const { values, setFieldValue, dirty, initialValues, touched } = useFormikContext<FormikValues>();
@@ -26,7 +27,7 @@ const ImageSearch: React.FC = () => {
   const { name: applicationNameTouched } = application as FormikTouched<{ name: boolean }>;
 
   const handleSearch = React.useCallback(
-    (searchTermImage: string) => {
+    (searchTermImage: string, isAllowInsecureRegistry = values.allowInsecureRegistry) => {
       setFieldValue('isSearchingForImage', true);
       setValidated(ValidatedOptions.default);
       const importImage = {
@@ -44,6 +45,7 @@ const ImageSearch: React.FC = () => {
                 kind: 'DockerImage',
                 name: _.trim(searchTermImage),
               },
+              importPolicy: { insecure: isAllowInsecureRegistry },
             },
           ],
         },
@@ -98,6 +100,7 @@ const ImageSearch: React.FC = () => {
       values.application.selectedKey,
       values.name,
       values.project.name,
+      values.allowInsecureRegistry,
       initialValues.route.targetPort,
     ],
   );
@@ -131,7 +134,8 @@ const ImageSearch: React.FC = () => {
       return;
     }
     !nameTouched && setFieldValue('name', '');
-    values.application.selectedKey !== UNASSIGNED_KEY &&
+    !values.application.isInContext &&
+      values.application.selectedKey !== UNASSIGNED_KEY &&
       !applicationNameTouched &&
       setFieldValue('application.name', '');
   };
@@ -198,9 +202,18 @@ const ImageSearch: React.FC = () => {
           className="co-alert"
           variant="success"
           title={`Secret ${newImageSecret} was created.`}
-          action={<AlertActionCloseButton onClose={() => shouldHideAlert(false)} />}
+          actionClose={<AlertActionCloseButton onClose={() => shouldHideAlert(false)} />}
         />
       )}
+      <div className="odc-image-search__advanced-options">
+        <CheckboxField
+          name="allowInsecureRegistry"
+          label="Allow images from insecure registries"
+          onChange={(val: boolean) => {
+            values.searchTerm && handleSearch(values.searchTerm, val);
+          }}
+        />
+      </div>
     </>
   );
 };
