@@ -1,12 +1,12 @@
 import * as React from 'react';
 import { shallow } from 'enzyme';
-import { HorizontalNav, PageHeading } from '@console/internal/components/utils';
+import * as utils from '@console/internal/components/utils';
 import { PageContents } from '../MonitoringPage';
-import ProjectListPage from '../../projects/ProjectListPage';
+import CreateProjectListPage from '../../projects/CreateProjectListPage';
 
 describe('Monitoring Page ', () => {
   let monPageProps: React.ComponentProps<typeof PageContents>;
-
+  const spyUseAccessReview = jest.spyOn(utils, 'useAccessReview');
   it('should render ProjectList page when in all-projects namespace', () => {
     monPageProps = {
       match: {
@@ -17,11 +17,37 @@ describe('Monitoring Page ', () => {
       },
     };
     const component = shallow(<PageContents {...monPageProps} />);
-    expect(component.find(ProjectListPage).exists()).toBe(true);
-    expect(component.find(ProjectListPage).prop('title')).toBe('Monitoring');
+    expect(component.find(CreateProjectListPage).exists()).toBe(true);
+    expect(component.find(CreateProjectListPage).prop('title')).toBe('Monitoring');
   });
 
   it('should render all Tabs of Monitoring page for selected project', () => {
+    spyUseAccessReview.mockReturnValue(true);
+    const expectedTabs: string[] = ['Dashboard', 'Metrics', 'Alerts', 'Events'];
+    monPageProps = {
+      match: {
+        path: '/dev-monitoring/ns/:ns',
+        url: '/dev-monitoring/ns/test-proj',
+        isExact: true,
+        params: {
+          ns: 'test-proj',
+        },
+      },
+    };
+
+    const component = shallow(<PageContents {...monPageProps} />);
+    expect(component.find(utils.PageHeading).exists()).toBe(true);
+    expect(component.find(utils.PageHeading).prop('title')).toBe('Monitoring');
+    expect(component.find(utils.HorizontalNav).exists()).toBe(true);
+    const actualTabs = component
+      .find(utils.HorizontalNav)
+      .prop('pages')
+      .map((page) => page.name);
+    expect(actualTabs).toEqual(expectedTabs);
+  });
+
+  it('should not render the Alerts tab if user has no access to get prometheousRule resource', () => {
+    spyUseAccessReview.mockReturnValue(false);
     const expectedTabs: string[] = ['Dashboard', 'Metrics', 'Events'];
     monPageProps = {
       match: {
@@ -35,11 +61,8 @@ describe('Monitoring Page ', () => {
     };
 
     const component = shallow(<PageContents {...monPageProps} />);
-    expect(component.find(PageHeading).exists()).toBe(true);
-    expect(component.find(PageHeading).prop('title')).toBe('Monitoring');
-    expect(component.find(HorizontalNav).exists()).toBe(true);
     const actualTabs = component
-      .find(HorizontalNav)
+      .find(utils.HorizontalNav)
       .prop('pages')
       .map((page) => page.name);
     expect(actualTabs).toEqual(expectedTabs);
