@@ -9,15 +9,17 @@ import {
   observer,
   useHover,
   useSelection,
-} from '@console/topology';
-import { getTopologyResourceObject } from '../../topology-utils';
+  WithContextMenuProps,
+} from '@patternfly/react-topology';
+import { getResource } from '../../topology-utils';
 import './BaseEdge.scss';
 
 type BaseEdgeProps = {
   element: Edge;
   dragging?: boolean;
   className?: string;
-} & WithRemoveConnectorProps;
+} & WithRemoveConnectorProps &
+  Partial<WithContextMenuProps>;
 
 const ObservedBaseEdge: React.FC<BaseEdgeProps> = ({
   element,
@@ -26,12 +28,13 @@ const ObservedBaseEdge: React.FC<BaseEdgeProps> = ({
   onHideRemoveConnector,
   children,
   className,
+  onContextMenu,
 }) => {
   const [hover, hoverRef] = useHover();
-  const [selected, onSelect] = useSelection(false, true);
+  const [selected, onSelect] = useSelection({ controlled: true });
   const startPoint = element.getStartPoint();
   const endPoint = element.getEndPoint();
-  const resourceObj = getTopologyResourceObject(element.getSource().getData());
+  const resourceObj = getResource(element.getSource());
   const resourceModel = resourceObj && modelFor(referenceFor(resourceObj));
 
   const editAccess = useAccessReview({
@@ -63,6 +66,7 @@ const ObservedBaseEdge: React.FC<BaseEdgeProps> = ({
           'is-selected': selected,
         })}
         onClick={onSelect}
+        onContextMenu={onContextMenu}
       >
         <line
           x1={startPoint.x}
