@@ -13,12 +13,18 @@ import {
   useHover,
   observer,
   createSvgIdUrl,
-} from '@console/topology';
+} from '@patternfly/react-topology';
 import { modelFor, referenceFor } from '@console/internal/module/k8s';
 import { useAccessReview } from '@console/internal/components/utils';
 import SvgBoxedText from '../../../svg/SvgBoxedText';
 import { getTopologyResourceObject } from '../../topology-utils';
-import { useDisplayFilters, useSearchFilter } from '../../filters';
+import {
+  getFilterById,
+  useDisplayFilters,
+  useSearchFilter,
+  useAllowEdgeCreation,
+  SHOW_LABELS_FILTER_ID,
+} from '../../filters';
 import { NodeShadows, NODE_SHADOW_FILTER_ID_HOVER, NODE_SHADOW_FILTER_ID } from '../NodeShadows';
 
 import './BaseNode.scss';
@@ -81,18 +87,20 @@ const ObservedBaseNode: React.FC<BaseNodeProps> = ({
   });
   const [filtered] = useSearchFilter(element.getLabel());
   const displayFilters = useDisplayFilters();
-  const showLabels = displayFilters.showLabels || hover;
+  const showLabelsFilter = getFilterById(SHOW_LABELS_FILTER_ID, displayFilters);
+  const showLabels = showLabelsFilter?.value || hover;
   const refs = useCombineRefs<SVGEllipseElement>(hoverRef, dragNodeRef);
+  const allowEdgeCreation = useAllowEdgeCreation();
 
   React.useLayoutEffect(() => {
-    if (editAccess) {
+    if (editAccess && allowEdgeCreation) {
       if (hover) {
         onShowCreateConnector && onShowCreateConnector();
       } else {
         onHideCreateConnector && onHideCreateConnector();
       }
     }
-  }, [hover, onShowCreateConnector, onHideCreateConnector, editAccess]);
+  }, [hover, onShowCreateConnector, onHideCreateConnector, editAccess, allowEdgeCreation]);
 
   return (
     <g
@@ -109,7 +117,7 @@ const ObservedBaseNode: React.FC<BaseNodeProps> = ({
       <g
         data-test-id="base-node-handler"
         onClick={onSelect}
-        onContextMenu={editAccess ? onContextMenu : null}
+        onContextMenu={onContextMenu}
         ref={refs}
       >
         <circle
