@@ -1,13 +1,18 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import { CodeIcon, BoltIcon, DatabaseIcon, CatalogIcon } from '@patternfly/react-icons';
+import {
+  BoltIcon,
+  CatalogIcon,
+  CodeIcon,
+  DatabaseIcon,
+  LaptopCodeIcon,
+} from '@patternfly/react-icons';
 import {
   Plugin,
   ModelDefinition,
   ModelFeatureFlag,
   KebabActions,
   HrefNavItem,
-  SeparatorNavItem,
   ResourceNSNavItem,
   ResourceClusterNavItem,
   ResourceListPage,
@@ -16,13 +21,16 @@ import {
   RoutePage,
   OverviewResourceTab,
   OverviewCRD,
+  OverviewResourceUtil,
   YAMLTemplate,
   OverviewTabSection,
   ReduxReducer,
+  GuidedTour,
 } from '@console/plugin-sdk';
 import { NamespaceRedirect } from '@console/internal/components/utils/namespace-redirect';
 import { FLAGS } from '@console/shared/src/constants';
 import { referenceForModel } from '@console/internal/module/k8s';
+import * as helmIcon from '@console/internal/imgs/logos/helm.svg';
 import {
   BuildConfigModel,
   ImageStreamModel,
@@ -33,14 +41,13 @@ import {
   ImageStreamImportsModel,
   ConfigMapModel,
 } from '@console/internal/models';
-import * as helmIcon from '@console/internal/imgs/logos/helm.svg';
 import * as models from './models';
 import { getKebabActionsForKind } from './utils/kebab-actions';
 import {
-  tknPipelineAndPipelineRunsResources,
   getPipelinesAndPipelineRunsForResource,
+  tknPipelineAndPipelineRunsResources,
 } from './utils/pipeline-plugin-utils';
-import { FLAG_OPENSHIFT_PIPELINE, ALLOW_SERVICE_BINDING } from './const';
+import { FLAG_OPENSHIFT_PIPELINE, ALLOW_SERVICE_BINDING, FLAG_OPENSHIFT_GITOPS } from './const';
 import {
   newPipelineTemplate,
   newTaskTemplate,
@@ -54,17 +61,30 @@ import * as yamlIcon from './images/yaml.svg';
 import * as importGitIcon from './images/from-git.svg';
 import * as dockerfileIcon from './images/dockerfile.svg';
 import * as pipelineIcon from './images/pipeline.svg';
+import { operatorResources } from './components/topology/operators/operator-resources';
+import {
+  HelmTopologyConsumedExtensions,
+  helmTopologyPlugin,
+} from './components/topology/helm/helmTopologyPlugin';
+import {
+  OperatorsTopologyConsumedExtensions,
+  operatorsTopologyPlugin,
+} from './components/topology/operators/operatorsTopologyPlugin';
+import { usePerspectiveDetection } from './utils/usePerspectiveDetection';
+import { getGuidedTour } from './components/guided-tour';
 
 const {
   ClusterTaskModel,
   PipelineModel,
   PipelineResourceModel,
   PipelineRunModel,
+  ConditionModel,
   TaskModel,
   TaskRunModel,
   EventListenerModel,
   TriggerTemplateModel,
   TriggerBindingModel,
+  ClusterTriggerBindingModel,
 } = models;
 
 type ConsumedExtensions =
@@ -72,7 +92,6 @@ type ConsumedExtensions =
   | ModelFeatureFlag
   | HrefNavItem
   | ResourceClusterNavItem
-  | SeparatorNavItem
   | ResourceNSNavItem
   | ResourceListPage
   | ResourceDetailsPage
@@ -82,9 +101,13 @@ type ConsumedExtensions =
   | KebabActions
   | OverviewResourceTab
   | OverviewCRD
+  | OverviewResourceUtil
   | YAMLTemplate
   | OverviewTabSection
-  | AddAction;
+  | AddAction
+  | GuidedTour
+  | HelmTopologyConsumedExtensions
+  | OperatorsTopologyConsumedExtensions;
 
 const plugin: Plugin<ConsumedExtensions> = [
   {
@@ -107,10 +130,18 @@ const plugin: Plugin<ConsumedExtensions> = [
       flag: ALLOW_SERVICE_BINDING,
     },
   },
+  {
+    type: 'FeatureFlag/Model',
+    properties: {
+      model: models.GitOpsServiceModel,
+      flag: FLAG_OPENSHIFT_GITOPS,
+    },
+  },
   {
     type: 'NavItem/Href',
     properties: {
       perspective: 'dev',
+      group: 'top',
       componentProps: {
         name: '+Add',
         href: '/add',
@@ -122,6 +153,7 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'NavItem/Href',
     properties: {
       perspective: 'dev',
+      group: 'top',
       componentProps: {
         name: 'Topology',
         href: '/topology',
@@ -136,10 +168,12 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'NavItem/Href',
     properties: {
       perspective: 'dev',
+      group: 'top',
       componentProps: {
         name: 'Monitoring',
         href: '/dev-monitoring',
         testID: 'monitoring-header',
+        'data-tour-id': 'tour-monitoring-nav',
       },
     },
     flags: {
@@ -150,19 +184,12 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'NavItem/Href',
     properties: {
       perspective: 'dev',
+      group: 'top',
       componentProps: {
         name: 'Search',
         href: '/search',
         testID: 'search-header',
-      },
-    },
-  },
-  {
-    type: 'NavItem/Separator',
-    properties: {
-      perspective: 'dev',
-      componentProps: {
-        testID: 'dev-separator',
+        'data-tour-id': 'tour-search-nav',
       },
     },
   },
@@ -170,6 +197,7 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'NavItem/ResourceNS',
     properties: {
       perspective: 'dev',
+      group: 'resources',
       componentProps: {
         name: 'Builds',
         resource: 'buildconfigs',
@@ -184,6 +212,7 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'NavItem/ResourceNS',
     properties: {
       perspective: 'dev',
+      group: 'resources',
       componentProps: {
         name: PipelineModel.labelPlural,
         resource: referenceForModel(PipelineModel),
@@ -198,6 +227,22 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'NavItem/Href',
     properties: {
       perspective: 'dev',
+      group: 'resources',
+      componentProps: {
+        name: 'Application Stages',
+        href: '/applicationstages',
+        testID: 'application-stages-header',
+      },
+    },
+    flags: {
+      required: [FLAG_OPENSHIFT_GITOPS],
+    },
+  },
+  {
+    type: 'NavItem/Href',
+    properties: {
+      perspective: 'dev',
+      group: 'resources',
       componentProps: {
         name: 'Helm',
         href: '/helm-releases',
@@ -212,6 +257,7 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'NavItem/Href',
     properties: {
       perspective: 'dev',
+      group: 'resources',
       componentProps: {
         name: 'Project',
         href: '/project-details',
@@ -226,18 +272,28 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'Overview/CRD',
     properties: {
       resources: tknPipelineAndPipelineRunsResources,
-      required: FLAG_OPENSHIFT_PIPELINE,
-      utils: getPipelinesAndPipelineRunsForResource,
+    },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
     },
   },
   {
-    type: 'NavItem/ResourceNS',
+    type: 'Overview/ResourceUtil',
+    properties: {
+      getResources: getPipelinesAndPipelineRunsForResource,
+    },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
+  },
+  {
+    type: 'NavItem/Href',
     properties: {
       perspective: 'admin',
       section: 'Pipelines',
       componentProps: {
         name: PipelineModel.labelPlural,
-        resource: referenceForModel(PipelineModel),
+        href: '/pipelines',
       },
     },
     flags: {
@@ -245,41 +301,13 @@ const plugin: Plugin<ConsumedExtensions> = [
     },
   },
   {
-    type: 'NavItem/ResourceNS',
-    properties: {
-      perspective: 'admin',
-      section: 'Pipelines',
-      componentProps: {
-        name: PipelineRunModel.labelPlural,
-        resource: referenceForModel(PipelineRunModel),
-      },
-    },
-    flags: {
-      required: [FLAG_OPENSHIFT_PIPELINE],
-    },
-  },
-  {
-    type: 'NavItem/ResourceNS',
-    properties: {
-      perspective: 'admin',
-      section: 'Pipelines',
-      componentProps: {
-        name: PipelineResourceModel.labelPlural,
-        resource: referenceForModel(PipelineResourceModel),
-      },
-    },
-    flags: {
-      required: [FLAG_OPENSHIFT_PIPELINE],
-    },
-  },
-  {
-    type: 'NavItem/ResourceNS',
+    type: 'NavItem/Href',
     properties: {
       perspective: 'admin',
       section: 'Pipelines',
       componentProps: {
         name: TaskModel.labelPlural,
-        resource: referenceForModel(TaskModel),
+        href: '/tasks',
       },
     },
     flags: {
@@ -287,27 +315,13 @@ const plugin: Plugin<ConsumedExtensions> = [
     },
   },
   {
-    type: 'NavItem/ResourceNS',
+    type: 'NavItem/Href',
     properties: {
       perspective: 'admin',
       section: 'Pipelines',
       componentProps: {
-        name: TaskRunModel.labelPlural,
-        resource: referenceForModel(TaskRunModel),
-      },
-    },
-    flags: {
-      required: [FLAG_OPENSHIFT_PIPELINE],
-    },
-  },
-  {
-    type: 'NavItem/ResourceCluster',
-    properties: {
-      perspective: 'admin',
-      section: 'Pipelines',
-      componentProps: {
-        name: ClusterTaskModel.labelPlural,
-        resource: referenceForModel(ClusterTaskModel),
+        name: 'Triggers',
+        href: '/triggers',
       },
     },
     flags: {
@@ -359,6 +373,30 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: PipelineResourceModel,
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines/detail-page-tabs/PipelineResourceDetailsPage' /* webpackChunkName: "pipelineresource-details" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: ConditionModel,
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines/detail-page-tabs/PipelineConditionDetailsPage' /* webpackChunkName: "pipelinecondition-details" */
+          )
+        ).default,
+    },
+  },
   {
     type: 'Page/Resource/Details',
     properties: {
@@ -371,6 +409,27 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: ClusterTaskModel,
+      loader: async () =>
+        (
+          await import(
+            './components/cluster-tasks/ClusterTaskDetailsPage' /* webpackChunkName: "clustertask-details" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: TaskModel,
+      loader: async () =>
+        (await import('./components/tasks/TaskDetailsPage' /* webpackChunkName: "task-details" */))
+          .default,
+    },
+  },
   {
     type: 'Page/Resource/Details',
     properties: {
@@ -407,6 +466,18 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: ClusterTriggerBindingModel,
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines/ClusterTriggerBindingPage' /* webpackChunkName: "cluster-trigger-binding-details" */
+          )
+        ).default,
+    },
+  },
   {
     type: 'Page/Resource/List',
     properties: {
@@ -441,6 +512,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       getLandingPageURL: () => '/topology',
       getK8sLandingPageURL: () => '/add',
       getImportRedirectURL: (project) => `/topology/ns/${project}`,
+      usePerspectiveDetection,
     },
   },
   {
@@ -450,11 +522,16 @@ const plugin: Plugin<ConsumedExtensions> = [
       path: [
         '/add',
         '/import',
+        '/import-sample',
+        '/samples',
         '/topology',
         '/deploy-image',
         '/project-details',
         '/dev-monitoring',
         '/helm-releases',
+        '/pipelines',
+        '/tasks',
+        '/triggers',
       ],
       component: NamespaceRedirect,
     },
@@ -488,6 +565,32 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: '/applicationstages',
+      loader: async () =>
+        (
+          await import(
+            './components/gitops/GitOpsListPage' /* webpackChunkName: "dev-console-gitops" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: '/applicationstages/:appName',
+      loader: async () =>
+        (
+          await import(
+            './components/gitops/GitOpsDetailsPage' /* webpackChunkName: "dev-console-gitops" */
+          )
+        ).default,
+    },
+  },
   {
     type: 'Page/Route',
     properties: {
@@ -514,6 +617,32 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: ['/samples/all-namespaces', '/samples/ns/:ns'],
+      loader: async () =>
+        (
+          await import(
+            './components/import/SamplesCatalog' /* webpackChunkName: "dev-console-samples-catalog" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: ['/samples/ns/:ns/:is/:isNs'],
+      loader: async () =>
+        (
+          await import(
+            './components/import/ImportSamplePage' /* webpackChunkName: "dev-console-import-sample" */
+          )
+        ).default,
+    },
+  },
   {
     type: 'Page/Route',
     properties: {
@@ -541,6 +670,45 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: false,
+      path: ['/pipelines/all-namespaces', '/pipelines/ns/:ns'],
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines-lists/PipelinesListsPage' /* webpackChunkName: "admin-pipeline" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: false,
+      path: ['/tasks/all-namespaces', '/tasks/ns/:ns'],
+      loader: async () =>
+        (
+          await import(
+            './components/tasks/list-page/TasksListsPage' /* webpackChunkName: "admin-tasks`" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: false,
+      path: ['/triggers/all-namespaces', '/triggers/ns/:ns'],
+      loader: async () =>
+        (
+          await import(
+            './components/triggers-lists/TriggersPage' /* webpackChunkName: "admin-triggers" */
+          )
+        ).default,
+    },
+  },
   {
     type: 'Page/Route',
     properties: {
@@ -693,6 +861,32 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: false,
+      path: ['/dev-monitoring/ns/:ns/alerts/:ruleID'],
+      loader: async () =>
+        (
+          await import(
+            './components/monitoring/alerts/MonitoringAlertsRulesDetailsPage' /* webpackChunkName: "dev-console-monitoring-alerts" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: false,
+      path: ['/dev-monitoring/ns/:ns/rules/:id'],
+      loader: async () =>
+        (
+          await import(
+            './components/monitoring/alerts/MonitoringAlertsRulesDetailsPage' /* webpackChunkName: "dev-console-monitoring-rules" */
+          )
+        ).default,
+    },
+  },
   {
     type: 'Page/Route',
     properties: {
@@ -747,6 +941,16 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: ['/workload-hpa/ns/:ns/:resourceRef/:name'],
+      loader: async () =>
+        (await import('./components/hpa/HPAPage' /* webpackChunkName: "hpa-on-workload`" */))
+          .default,
+    },
+  },
   {
     type: 'ReduxReducer',
     properties: {
@@ -795,13 +999,35 @@ const plugin: Plugin<ConsumedExtensions> = [
       template: newClusterTaskTemplate,
     },
   },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'import-from-samples',
+      url: '/samples',
+      label: 'Samples',
+      description: 'Create an application from a code sample',
+      icon: <LaptopCodeIcon />,
+      accessReview: [
+        BuildConfigModel,
+        ImageStreamModel,
+        DeploymentConfigModel,
+        SecretModel,
+        RouteModel,
+        ServiceModel,
+      ].map((model) => ({
+        group: model.apiGroup || '',
+        resource: model.plural,
+        verb: 'create',
+      })),
+    },
+  },
   {
     type: 'AddAction',
     properties: {
       id: 'import-from-git',
       url: '/import',
       label: 'From Git',
-      description: 'Import code from your git repository to be built and deployed',
+      description: 'Import code from your Git repository to be built and deployed',
       icon: importGitIcon,
       accessReview: [
         BuildConfigModel,
@@ -846,7 +1072,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       id: 'import-from-dockerfile',
       url: '/import?importType=docker',
       label: 'From Dockerfile',
-      description: 'Import your Dockerfile from your git repo to be built and deployed',
+      description: 'Import your Dockerfile from your Git repository to be built and deployed',
       icon: dockerfileIcon,
       accessReview: [
         BuildConfigModel,
@@ -932,6 +1158,24 @@ const plugin: Plugin<ConsumedExtensions> = [
       ],
     },
   },
+  {
+    type: 'Overview/CRD',
+    properties: {
+      resources: operatorResources,
+    },
+    flags: {
+      required: [ALLOW_SERVICE_BINDING],
+    },
+  },
+  {
+    type: 'GuidedTour',
+    properties: {
+      perspective: 'dev',
+      tour: getGuidedTour(),
+    },
+  },
+  ...helmTopologyPlugin,
+  ...operatorsTopologyPlugin,
 ];
 
 export default plugin;
