@@ -38,6 +38,9 @@ export const getAddPageUrl = (
     case ImportOptions.EVENTSOURCE:
       pageUrl = `/event-source/ns/${ns}`;
       break;
+    case ImportOptions.EVENTPUBSUB:
+      pageUrl = `/add/ns/${ns}`;
+      break;
     default:
       throw new Error('Invalid Import option provided');
   }
@@ -70,6 +73,8 @@ export type KebabAction = (
   accessData?: string[],
 ) => KebabOption;
 
+export type MenuOptions = (KebabAction | KebabOption)[];
+
 export const createKebabAction: KebabFactory = (label, icon, importType, checkAccess) => (
   obj: K8sResourceKind,
   namespace: string,
