@@ -7,7 +7,11 @@ import { DropdownField, getFieldId } from '@console/shared';
 import FormSection from '@console/dev-console/src/components/import/section/FormSection';
 import ServiceAccountDropdown from '../../dropdowns/ServiceAccountDropdown';
 
-const ApiServerSection: React.FC = () => {
+interface ApiServerSectionProps {
+  title: string;
+}
+
+const ApiServerSection: React.FC<ApiServerSectionProps> = ({ title }) => {
   const { values, setFieldValue } = useFormikContext<FormikValues>();
   const initVal = values?.data?.apiserversource?.resources || [];
   const initialValueResources = !_.isEmpty(initVal)
@@ -30,12 +34,12 @@ const ApiServerSection: React.FC = () => {
     [setFieldValue],
   );
   const modeItems = {
-    Reference: 'Reference',
+    Ref: 'Ref',
     Resource: 'Resource',
   };
   const fieldId = getFieldId(values.type, 'res-input');
   return (
-    <FormSection title="ApiServerSource" extraMargin>
+    <FormSection title={title} extraMargin>
       <FormGroup
         fieldId={fieldId}
         label="Resource"
@@ -61,7 +65,7 @@ const ApiServerSection: React.FC = () => {
         name="data.apiserversource.mode"
         label="Mode"
         items={modeItems}
-        title={modeItems.Reference}
+        title={modeItems.Ref}
         helpText="The mode the receive adapter controller runs under"
         fullWidth
       />
