@@ -1,4 +1,5 @@
 import * as React from 'react';
+import * as _ from 'lodash';
 import { safeDump } from 'js-yaml';
 import { useFormikContext, FormikValues } from 'formik';
 import { YAMLEditorField } from '@console/shared';
@@ -9,7 +10,11 @@ import {
 } from '../../../utils/create-eventsources-utils';
 import { EventSourceFormData } from '../import-types';
 
-const YAMLEditorSection: React.FC = () => {
+interface YAMLEditorSectionProps {
+  title: string;
+}
+
+const YAMLEditorSection: React.FC<YAMLEditorSectionProps> = ({ title }) => {
   const { setFieldValue, setFieldTouched, values } = useFormikContext<FormikValues>();
   const formData = React.useRef(values);
   if (formData.current.type !== values.type) {
@@ -18,16 +23,23 @@ const YAMLEditorSection: React.FC = () => {
 
   React.useEffect(() => {
     if (!isKnownEventSource(values.type)) {
-      setFieldValue(
-        'yamlData',
-        safeDump(getEventSourcesDepResource(formData.current as EventSourceFormData)),
-      );
+      const {
+        project: { name: namespace },
+        data: { itemData },
+      } = formData.current;
+      const yamlDumpData = _.isEmpty(itemData?.data?.almData)
+        ? getEventSourcesDepResource(formData.current as EventSourceFormData)
+        : {
+            ...itemData.data.almData,
+            metadata: { ...itemData.data.almData.metadata, namespace },
+          };
+      setFieldValue('yamlData', safeDump(yamlDumpData));
       setFieldTouched('yamlData', true);
     }
   }, [values.type, setFieldTouched, setFieldValue]);
 
   return (
-    <FormSection title={values.type} flexLayout fullWidth>
+    <FormSection title={title} flexLayout fullWidth>
       <YAMLEditorField name="yamlData" />
     </FormSection>
   );
