@@ -6,6 +6,8 @@ import {
   EventSourceKafkaModel,
   EventSourcePingModel,
   EventSourceSinkBindingModel,
+  EventingIMCModel,
+  EventingKafkaChannelModel,
 } from '../../models';
 
 export const EventSources = {
@@ -16,7 +18,10 @@ export const EventSources = {
   PingSource: EventSourcePingModel.kind,
   SinkBinding: EventSourceSinkBindingModel.kind,
 };
-
+export const defaultChannels = {
+  InMemoryChannel: EventingIMCModel,
+  KafkaChannel: EventingKafkaChannelModel,
+};
 export interface ProjectData {
   name: string;
   displayName: string;
@@ -33,8 +38,12 @@ export interface EventSourceData {
   [x: string]: any;
 }
 
-export interface KnativeServiceName {
-  knativeService: string;
+export interface SinkResourceData {
+  apiVersion: string;
+  name: string;
+  kind: string;
+  key: string;
+  uri?: string;
 }
 
 export interface EventSourceFormData {
@@ -43,7 +52,8 @@ export interface EventSourceFormData {
   name: string;
   apiVersion: string;
   type: string;
-  sink: KnativeServiceName;
+  sinkType: string;
+  sink: SinkResourceData;
   limits: LimitsData;
   data?: EventSourceData;
   yamlData?: string;
@@ -65,3 +75,35 @@ export interface EventSourceListData {
   loaded: boolean;
   eventSourceList: NormalizedEventSources;
 }
+
+export enum SinkType {
+  Resource = 'resource',
+  Uri = 'uri',
+}
+
+export const EVENT_SOURCES_APP = 'event-sources-app';
+
+export const sourceSinkType = {
+  Resource: {
+    value: SinkType.Resource,
+    label: 'Resource',
+  },
+  Uri: {
+    value: SinkType.Uri,
+    label: 'URI',
+  },
+};
+export interface AddChannelFormData {
+  application: ApplicationData;
+  name: string;
+  namespace: string;
+  apiVersion: string;
+  type: string;
+  data?: EventSourceData;
+  yamlData?: string;
+}
+
+export interface ChannelListProps {
+  loaded: boolean;
+  channelList: string[];
+}
