@@ -6,5 +6,11 @@ export const FLAG_KNATIVE_SERVING_ROUTE = 'KNATIVE_SERVING_ROUTE';
 export const FLAG_KNATIVE_SERVING_SERVICE = 'KNATIVE_SERVING_SERVICE';
 export const KNATIVE_SERVING_LABEL = 'serving.knative.dev/service';
 export const KNATIVE_SERVING_APIGROUP = 'serving.knative.dev';
+export const KNATIVE_EVENTING_APIGROUP = 'eventing.knative.dev';
+export const KNATIVE_EVENT_MESSAGE_APIGROUP = 'messaging.knative.dev';
 export const KNATIVE_EVENT_SOURCE_APIGROUP_DEP = 'sources.eventing.knative.dev';
 export const KNATIVE_EVENT_SOURCE_APIGROUP = 'sources.knative.dev';
+export const STRIMZI_KAFKA_APIGROUP = 'kafka.strimzi.io';
+export const EVENT_SOURCE_LABEL = 'console.openshift.io/event-source';
+export const EVENT_SOURCE_ICON = 'console.openshift.io/icon';
+export const CAMEL_SOURCE_INTEGRATION = 'camel.apache.org/integration';
