@@ -1,13 +1,14 @@
-import {
-  chart_color_cyan_400 as knativeServingColor,
-  chart_color_red_300 as knativeEventingColor,
-} from '@patternfly/react-tokens';
+import { chart_color_cyan_400 as knativeServingColor } from '@patternfly/react-tokens/dist/js/chart_color_cyan_400';
+import { chart_color_red_300 as knativeEventingColor } from '@patternfly/react-tokens/dist/js/chart_color_red_300';
 import { K8sKind } from '@console/internal/module/k8s';
 import { BadgeType } from '@console/shared/src/components/badges/badge-factory';
 import {
   KNATIVE_EVENT_SOURCE_APIGROUP,
   KNATIVE_EVENT_SOURCE_APIGROUP_DEP,
   KNATIVE_SERVING_APIGROUP,
+  KNATIVE_EVENT_MESSAGE_APIGROUP,
+  KNATIVE_EVENTING_APIGROUP,
+  STRIMZI_KAFKA_APIGROUP,
 } from './const';
 
 const apiVersion = 'v1';
@@ -169,7 +170,7 @@ export const EventSourceCamelModel: K8sKind = {
 
 export const EventSourceKafkaModel: K8sKind = {
   apiGroup: KNATIVE_EVENT_SOURCE_APIGROUP,
-  apiVersion: 'v1beta1',
+  apiVersion: 'v1alpha1',
   kind: 'KafkaSource',
   label: 'KafkaSource',
   labelPlural: 'KafkaSources',
@@ -194,3 +195,129 @@ export const EventSourceSinkBindingModel: K8sKind = {
   crd: true,
   color: knativeEventingColor.value,
 };
+
+export const EventingSubscriptionModel: K8sKind = {
+  apiGroup: KNATIVE_EVENT_MESSAGE_APIGROUP,
+  apiVersion: 'v1beta1',
+  kind: 'Subscription',
+  label: 'Subscription',
+  labelPlural: 'Subscriptions',
+  plural: 'subscriptions',
+  id: 'subscriptioneventing',
+  abbr: 'S',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
+export const EventingIMCModel: K8sKind = {
+  apiGroup: KNATIVE_EVENT_MESSAGE_APIGROUP,
+  apiVersion: 'v1beta1',
+  kind: 'InMemoryChannel',
+  label: 'InMemoryChannel',
+  labelPlural: 'inmemorychannels',
+  plural: 'inmemorychannels',
+  id: 'inmemorychannel',
+  abbr: 'IMC',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
+export const EventingChannelModel: K8sKind = {
+  apiGroup: KNATIVE_EVENT_MESSAGE_APIGROUP,
+  apiVersion: 'v1beta1',
+  kind: 'Channel',
+  label: 'Channel',
+  labelPlural: 'channels',
+  plural: 'channels',
+  id: 'channel',
+  abbr: 'C',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
+export const EventingKafkaChannelModel: K8sKind = {
+  apiGroup: KNATIVE_EVENT_MESSAGE_APIGROUP,
+  apiVersion: 'v1beta1',
+  kind: 'KafkaChannel',
+  label: 'Kafka Channel',
+  labelPlural: 'Kafka Channels',
+  plural: 'kafkachannels',
+  id: 'kafkaChannel',
+  abbr: 'KC',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
+export const EventingBrokerModel: K8sKind = {
+  apiGroup: KNATIVE_EVENTING_APIGROUP,
+  apiVersion: 'v1beta1',
+  kind: 'Broker',
+  label: 'Broker',
+  labelPlural: 'Brokers',
+  plural: 'brokers',
+  id: 'broker',
+  abbr: 'B',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
+export const EventingTriggerModel: K8sKind = {
+  apiGroup: KNATIVE_EVENTING_APIGROUP,
+  apiVersion: 'v1beta1',
+  kind: 'Trigger',
+  label: 'Trigger',
+  labelPlural: 'Triggers',
+  plural: 'triggers',
+  id: 'trigger',
+  abbr: 'T',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
+export const CamelIntegrationModel: K8sKind = {
+  apiGroup: 'camel.apache.org',
+  apiVersion: 'v1',
+  kind: 'Integration',
+  label: 'Integration',
+  labelPlural: 'Integrations',
+  plural: 'integrations',
+  id: 'integration',
+  abbr: 'I',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
+export const KafkaModel: K8sKind = {
+  apiGroup: STRIMZI_KAFKA_APIGROUP,
+  apiVersion: 'v1beta1',
+  kind: 'Kafka',
+  label: 'Kafka',
+  labelPlural: 'Kafkas',
+  plural: 'kafkas',
+  id: 'kafka',
+  abbr: 'K',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
+export const KafkaTopicModel: K8sKind = {
+  apiGroup: STRIMZI_KAFKA_APIGROUP,
+  apiVersion: 'v1beta1',
+  kind: 'KafkaTopic',
+  label: 'KafkaTopic',
+  labelPlural: 'KafkaTopics',
+  plural: 'kafkatopics',
+  id: 'kafkatopic',
+  abbr: 'KT',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
