@@ -1,13 +1,14 @@
-import { browser } from 'protractor';
 import * as _ from 'lodash';
+import { browser } from 'protractor';
 import { testName } from '@console/internal-integration-tests/protractor.conf';
 import { click, createResource, deleteResource } from '@console/shared/src/test-utils/utils';
 import { isLoaded } from '@console/internal-integration-tests/views/crud.view';
 import * as bootOrderView from '../views/dialogs/editBootOrderView';
+import { saveButton } from '../views/kubevirtUIResource.view';
 import { getBootableDevicesInOrder, getNonBootableDevices } from '../../src/selectors/vm/devices';
-import { VM_CREATE_AND_EDIT_TIMEOUT_SECS } from './utils/consts';
+import { VM_CREATE_AND_EDIT_TIMEOUT_SECS } from './utils/constants/common';
 import { VirtualMachine } from './models/virtualMachine';
-import { getVMManifest, hddDisk } from './utils/mocks';
+import { getVMManifest, hddDisk } from './mocks/mocks';
 import { getRandStr, getSelectOptions, selectOptionByText } from './utils/utils';
 import { dragAndDrop } from './utils/scripts/drag-drop';
 
@@ -18,17 +19,13 @@ describe('KubeVirt VM detail - Boot Order Dialog', () => {
   beforeAll(async () => {
     createResource(testVM);
     await vm.addDisk(hddDisk);
+    await vm.navigateToDetail();
   });
 
   afterAll(() => {
     deleteResource(testVM);
   });
 
-  beforeEach(async () => {
-    await vm.navigateToDetail();
-    await vm.modalEditBootOrder();
-  });
-
   afterEach(async () => {
     await vm.closeModalDialog();
   });
@@ -50,10 +47,11 @@ describe('KubeVirt VM detail - Boot Order Dialog', () => {
   it(
     'ID(CNV-3549) Deletes bootable device',
     async () => {
+      await vm.modalEditBootOrder();
       const FIRST_DEVICE_POSITION = 1;
       const initialBootableDevices = getBootableDevicesInOrder(vm.getResource());
       await click(bootOrderView.deleteDeviceButton(FIRST_DEVICE_POSITION));
-      await click(bootOrderView.saveButton);
+      await click(saveButton);
       // Wait for the boot Order to update
       await bootOrderView.waitForBootDevicesCount(
         vm.name,
@@ -74,6 +72,7 @@ describe('KubeVirt VM detail - Boot Order Dialog', () => {
   it(
     'ID(CNV-3548) Adds bootable device',
     async () => {
+      await vm.modalEditBootOrder();
       const initialVMObject = vm.getResource();
       const initialBootableDevices = getBootableDevicesInOrder(initialVMObject);
       const nonBootableDevices = getNonBootableDevices(initialVMObject).map(
@@ -91,7 +90,7 @@ describe('KubeVirt VM detail - Boot Order Dialog', () => {
         bootOrderView.addDeviceSelect,
         nonBootableDevicesSelectOptions[nonBootableDevicesSelectOptions.length - 1],
       );
-      await click(bootOrderView.saveButton);
+      await click(saveButton);
       // Wait for the boot Order to update
       await bootOrderView.waitForBootDevicesCount(
         vm.name,
@@ -112,19 +111,20 @@ describe('KubeVirt VM detail - Boot Order Dialog', () => {
   it(
     'ID(CNV-3547) Drags and drops to change boot order',
     async () => {
+      await vm.modalEditBootOrder();
       const initialBootableDevices = getBootableDevicesInOrder(vm.getResource()).map(
         (device) => `${_.get(device, 'value.name')}`,
       );
 
       // Find devices at indexes 0 and 1 representing first and second device
-      const source = bootOrderView.draggablePointer(0);
-      const destination = bootOrderView.draggablePointer(1);
+      const source = bootOrderView.draggablePointer(1);
+      const destination = bootOrderView.draggablePointer(2);
 
       await browser.executeScript(dragAndDrop, source, destination);
       // Wait for the DOM structure to update
       await browser.sleep(300);
       // Click and wait for the changes to be applied
-      await click(bootOrderView.saveButton);
+      await click(saveButton);
       await isLoaded();
       // Renavigate to force the page to update
       await vm.navigateToDetail();
