@@ -1,6 +1,8 @@
 import * as _ from 'lodash';
-import { ConfigMapKind } from '@console/internal/module/k8s';
+import { ConfigMapKind, K8sResourceKind } from '@console/internal/module/k8s';
 import { AccessMode, VolumeMode } from '../../constants/vm/storage';
+import { getAnnotations } from '@console/shared';
+import { DEFAULT_SC_ANNOTATION } from '../../constants/sc';
 
 const getSCConfigMapAttribute = (
   storageClassConfigMap: ConfigMapKind,
@@ -48,3 +50,6 @@ export const getDefaultSCAccessModes = (
 
   return accessMode ? [accessMode] : [AccessMode.READ_WRITE_ONCE];
 };
+
+export const getGefaultStorageClass = (storageClasses: K8sResourceKind[]): K8sResourceKind =>
+  (storageClasses || []).find((sc) => getAnnotations(sc, {})[DEFAULT_SC_ANNOTATION] === 'true');
