@@ -11,12 +11,14 @@ import {
   ResourceNSNavItem,
   RoutePage,
   YAMLTemplate,
+  ProjectDashboardInventoryItem,
 } from '@console/plugin-sdk';
 import { GridPosition } from '@console/shared/src/components/dashboard/DashboardGrid';
 import { referenceForModel } from '@console/internal/module/k8s';
 import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager';
 import { OCS_FLAG } from '@console/ceph-storage-plugin/src/features';
 import * as models from './models';
+import { getObcStatusGroups } from './components/buckets-card/utils';
 
 type ConsumedExtensions =
   | ModelFeatureFlag
@@ -28,7 +30,8 @@ type ConsumedExtensions =
   | ResourceListPage
   | ResourceDetailsPage
   | YAMLTemplate
-  | RoutePage;
+  | RoutePage
+  | ProjectDashboardInventoryItem;
 
 const NOOBAA_FLAG = 'NOOBAA';
 
@@ -50,7 +53,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import('./components/bucket-class/create-bc' /* webpackChunkName: "create-bc" */).then(
           (m) => m.default,
         ),
-      required: NOOBAA_FLAG,
+    },
+    flags: {
+      required: [NOOBAA_FLAG],
     },
   },
   {
@@ -63,7 +68,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import('./components/noobaa-operator/noobaa-page' /* webpackChunkName: "create-bc" */).then(
           (m) => m.default,
         ),
-      required: NOOBAA_FLAG,
+    },
+    flags: {
+      required: [NOOBAA_FLAG],
     },
   },
   {
@@ -80,7 +87,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/create-backingstore-page/create-bs-page' /* webpackChunkName: "create-bs" */
         ).then((m) => m.default),
-      required: NOOBAA_FLAG,
+    },
+    flags: {
+      required: [NOOBAA_FLAG],
     },
   },
   {
@@ -135,7 +144,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       position: GridPosition.LEFT,
       loader: () =>
         import(
-          './components/object-data-reduction-card/object-data-reduction-card' /* webpackChunkName: "object-service-data-reduction-card" */
+          './components/storage-efficiency-card/storage-efficiency-card' /* webpackChunkName: "object-service-storage-efficiency-card" */
         ).then((m) => m.default),
     },
     flags: {
@@ -286,7 +295,20 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/object-bucket-claim-page/create-obc' /* webpackChunkName: "create-obc" */
         ).then((m) => m.CreateOBCPage),
-      required: NOOBAA_FLAG,
+    },
+    flags: {
+      required: [NOOBAA_FLAG],
+    },
+  },
+  {
+    type: 'Project/Dashboard/Inventory/Item',
+    properties: {
+      model: models.NooBaaObjectBucketClaimModel,
+      useAbbr: true,
+      mapper: getObcStatusGroups,
+    },
+    flags: {
+      required: [NOOBAA_FLAG],
     },
   },
 ];
