@@ -1,6 +1,6 @@
 import * as React from 'react';
-import { Link, match as RouterMatch } from 'react-router-dom';
 import * as _ from 'lodash';
+import { Link, match as RouterMatch } from 'react-router-dom';
 import { connect } from 'react-redux';
 import * as classNames from 'classnames';
 import { sortable, wrappable } from '@patternfly/react-table';
@@ -12,10 +12,17 @@ import {
   Card,
   CardBody,
   CardFooter,
-  CardHeader,
   Popover,
+  CardTitle,
 } from '@patternfly/react-core';
-import { ALL_NAMESPACES_KEY, Status, WarningStatus, getNamespace, getUID } from '@console/shared';
+import {
+  ALL_NAMESPACES_KEY,
+  Status,
+  WarningStatus,
+  getNamespace,
+  getUID,
+  StatusIconAndText,
+} from '@console/shared';
 import {
   DetailsPage,
   Table,
@@ -29,11 +36,13 @@ import {
   modelFor,
   referenceForModel,
   referenceFor,
+  groupVersionFor,
   GroupVersionKind,
   K8sKind,
   k8sKill,
   k8sPatch,
   k8sGet,
+  K8sResourceCommon,
 } from '@console/internal/module/k8s';
 import { ResourceEventStream } from '@console/internal/components/events';
 import { Conditions } from '@console/internal/components/conditions';
@@ -46,6 +55,7 @@ import {
   Timestamp,
   SectionHeading,
   ResourceSummary,
+  ResourceStatus,
   ScrollToTopOnMount,
   AsyncComponent,
   ExternalLink,
@@ -57,7 +67,9 @@ import {
   KebabOption,
   resourceObjPath,
   KebabAction,
+  openshiftHelpBase,
 } from '@console/internal/components/utils';
+import { useK8sGet } from '@console/internal/components/utils/k8s-get-hook';
 import { useAccessReview } from '@console/internal/components/utils/rbac';
 import { RootState } from '@console/internal/redux';
 import {
@@ -78,13 +90,22 @@ import {
   PackageManifestKind,
   SubscriptionKind,
 } from '../types';
+import { operatorTypeAnnotation, nonStandaloneAnnotationValue } from '../const';
 import { subscriptionForCSV, getSubscriptionStatus } from '../status/csv-status';
 import { getInternalObjects, isInternalObject } from '../utils';
 import { ProvidedAPIsPage, ProvidedAPIPage } from './operand';
 import { createUninstallOperatorModal } from './modals/uninstall-operator-modal';
 import { operatorGroupFor, operatorNamespaceFor } from './operator-group';
-import { SubscriptionDetails, catalogSourceForSubscription } from './subscription';
+import {
+  SubscriptionDetails,
+  catalogSourceForSubscription,
+  upgradeRequiresApproval,
+  UpgradeApprovalLink,
+} from './subscription';
+import { RedExclamationCircleIcon } from '@console/shared/src/components/status/icons';
 import { ClusterServiceVersionLogo, referenceForProvidedAPI, providedAPIsFor } from './index';
+import { getBreadcrumbPath } from '@console/internal/components/utils/breadcrumbs';
+import { CreateInitializationResourceButton } from './operator-install-page';
 
 const clusterServiceVersionStateToProps = (state: RootState): ClusterServiceVersionStateProps => {
   return {
@@ -207,14 +228,39 @@ const menuActionsForCSV = (
     : [() => editSubscription(subscription), () => uninstall(subscription, csv)];
 };
 
+const SourceMissingStatus = () => (
+  <>
+    <WarningStatus title="Cannot update" />
+    <span className="text-muted">Catalog source was removed.</span>
+  </>
+);
+
+const SubscriptionStatus = ({ muted = false, subscription }) => {
+  if (!subscription) {
+    return null;
+  }
+
+  if (upgradeRequiresApproval(subscription)) {
+    return <UpgradeApprovalLink subscription={subscription} />;
+  }
+
+  const subscriptionStatus = getSubscriptionStatus(subscription);
+  return (
+    <span className={muted ? 'text-muted' : 'co-icon-and-text'}>
+      {muted ? (
+        subscriptionStatus.title
+      ) : (
+        <Status status={subscriptionStatus.status || 'Unknown'} />
+      )}
+    </span>
+  );
+};
+
 const ClusterServiceVersionStatus: React.FC<ClusterServiceVersionStatusProps> = ({
-  catalogSourceMissing,
   obj,
   subscription,
 }) => {
-  const status = _.get(obj, 'status.phase');
-  const subscriptionStatus = getSubscriptionStatus(subscription);
-
+  const status = obj?.status?.phase;
   if (obj.metadata.deletionTimestamp) {
     return (
       <span className="co-icon-and-text">
@@ -222,22 +268,12 @@ const ClusterServiceVersionStatus: React.FC<ClusterServiceVersionStatusProps> =
       </span>
     );
   }
-
-  if (catalogSourceMissing) {
-    return (
-      <>
-        <WarningStatus title="Cannot update" />
-        <span className="text-muted">Catalog source was removed</span>
-      </>
-    );
-  }
-
   return status ? (
     <>
       <span className="co-icon-and-text">
         <Status status={status} />
       </span>
-      {subscription && <span className="text-muted">{subscriptionStatus.title}</span>}
+      <SubscriptionStatus muted subscription={subscription} />
     </>
   ) : null;
 };
@@ -319,11 +355,11 @@ export const NamespacedClusterServiceVersionTableRow = withFallback<
       {/* Status */}
       <TableData className={statusColumnClass}>
         <div className="co-clusterserviceversion-row__status">
-          <ClusterServiceVersionStatus
-            catalogSourceMissing={catalogSourceMissing}
-            obj={obj}
-            subscription={subscription}
-          />
+          {catalogSourceMissing ? (
+            <SourceMissingStatus />
+          ) : (
+            <ClusterServiceVersionStatus obj={obj} subscription={subscription} />
+          )}
         </div>
       </TableData>
 
@@ -378,23 +414,7 @@ const NamespacedSubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
   const menuActions = [Kebab.factory.Edit, () => uninstall(obj)];
   const namespace = getNamespace(obj);
   const route = resourceObjPath(obj, referenceForModel(SubscriptionModel));
-  const subscriptionState = _.get(obj, 'status.state', 'Unknown');
   const uid = getUID(obj);
-  const getStatus = () => {
-    if (catalogSourceMissing) {
-      return (
-        <>
-          <WarningStatus title="Cannot update" />
-          <span className="text-muted">Catalog source was removed</span>
-        </>
-      );
-    }
-    return (
-      <span className="co-icon-and-text">
-        <Status status={subscriptionState} />
-      </span>
-    );
-  };
 
   return (
     <TableRow id={uid} trKey={rowKey} index={index} style={style}>
@@ -423,7 +443,9 @@ const NamespacedSubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
       </TableData>
 
       {/* Status */}
-      <TableData className={statusColumnClass}>{getStatus()}</TableData>
+      <TableData className={statusColumnClass}>
+        {catalogSourceMissing ? <SourceMissingStatus /> : <SubscriptionStatus subscription={obj} />}
+      </TableData>
 
       {/* Last Updated */}
       <TableData className={lastUpdatedColumnClass}>
@@ -510,19 +532,34 @@ export const NamespacedClusterServiceVersionList: React.SFC<ClusterServiceVersio
   );
   const NoDataEmptyMsg = () => <MsgBox title="No Operators Found" detail={noDataDetail} />;
 
-  const isCopiedCSV = (source, kind) => {
+  const isCopiedCSV = (source: ClusterServiceVersionKind, kind: string) => {
     return (
-      referenceForModel(ClusterServiceVersionModel) === kind && source.status?.reason === 'Copied'
+      referenceForModel(ClusterServiceVersionModel) === kind &&
+      (source.status?.reason === 'Copied' || source.metadata?.labels?.['olm.copiedFrom'])
     );
   };
 
-  const removeCopiedCSVs = (operators: (ClusterServiceVersionKind | SubscriptionKind)[]) => {
+  const isStandaloneCSV = (operator: ClusterServiceVersionKind) => {
+    return (
+      operator.metadata.annotations?.[operatorTypeAnnotation] !== nonStandaloneAnnotationValue ||
+      operator.status?.phase === ClusterServiceVersionPhase.CSVPhaseFailed
+    );
+  };
+
+  const filterOperators = (
+    operators: (ClusterServiceVersionKind | SubscriptionKind)[],
+    allNamespaceActive: boolean,
+  ): (ClusterServiceVersionKind | SubscriptionKind)[] => {
     return operators.filter((source) => {
       const kind = referenceFor(source);
-      if (isSubscription(kind)) {
+      if (isSubscription(source)) {
         return true;
       }
-      return !isCopiedCSV(source, kind);
+      const csv = source as ClusterServiceVersionKind;
+      if (allNamespaceActive) {
+        return !isCopiedCSV(csv, kind) && isStandaloneCSV(csv);
+      }
+      return isStandaloneCSV(csv);
     });
   };
 
@@ -552,37 +589,14 @@ export const NamespacedClusterServiceVersionList: React.SFC<ClusterServiceVersio
     const olmOperatorNamespace = obj.metadata?.annotations?.['olm.operatorNamespace'];
     return olmOperatorNamespace ?? getNamespace(obj);
   };
+  const allNamespaceActive = activeNamespace === ALL_NAMESPACES_KEY;
 
-  return activeNamespace === ALL_NAMESPACES_KEY ? (
+  return (
     <Table
-      data={removeCopiedCSVs(data) as any[]}
+      data={filterOperators(data, allNamespaceActive)}
       {...rest}
       aria-label="Installed Operators"
-      Header={AllProjectsTableHeader}
-      Row={(rowArgs: RowFunctionArgs<ClusterServiceVersionKind | SubscriptionKind>) => (
-        <InstalledOperatorTableRow
-          obj={rowArgs.obj}
-          index={rowArgs.index}
-          rowKey={rowArgs.key}
-          style={rowArgs.style}
-          catalogSources={catalogSources.data}
-          subscriptions={subscriptions.data}
-        />
-      )}
-      EmptyMsg={NoOperatorsMatchFilterMsg}
-      NoDataEmptyMsg={NoDataEmptyMsg}
-      virtualize
-      customSorts={{
-        formatTargetNamespaces,
-        getOperatorNamespace,
-      }}
-    />
-  ) : (
-    <Table
-      data={data}
-      {...rest}
-      aria-label="Installed Operators"
-      Header={SingleProjectTableHeader}
+      Header={allNamespaceActive ? AllProjectsTableHeader : SingleProjectTableHeader}
       Row={(rowArgs: RowFunctionArgs<ClusterServiceVersionKind | SubscriptionKind>) => (
         <InstalledOperatorTableRow
           obj={rowArgs.obj}
@@ -611,17 +625,17 @@ export const ClusterServiceVersionList = connect(clusterServiceVersionStateToPro
 export const ClusterServiceVersionsPage: React.FC<ClusterServiceVersionsPageProps> = (props) => {
   const title = 'Installed Operators';
   const helpText = (
-    <p className="co-help-text">
+    <>
       Installed Operators are represented by Cluster Service Versions within this namespace. For
       more information, see the{' '}
       <ExternalLink
-        href="https://github.com/operator-framework/operator-lifecycle-manager/blob/master/doc/design/architecture.md"
-        text="Operator Lifecycle Manager documentation"
+        href={`${openshiftHelpBase}operators/olm-what-operators-are.html`}
+        text="Understanding Operators documentation"
       />
       . Or create an Operator and Cluster Service Version using the{' '}
       <ExternalLink href="https://github.com/operator-framework/operator-sdk" text="Operator SDK" />
       .
-    </p>
+    </>
   );
 
   const flatten = ({ clusterServiceVersions, subscriptions }) =>
@@ -682,6 +696,7 @@ export const MarkdownView = (props: {
   content: string;
   styles?: string;
   exactHeight?: boolean;
+  truncateContent?: boolean;
 }) => {
   return (
     <AsyncComponent
@@ -694,23 +709,31 @@ export const MarkdownView = (props: {
 };
 
 export const CRDCard: React.SFC<CRDCardProps> = (props) => {
-  const { csv, crd, canCreate } = props;
+  const { csv, crd, canCreate, required = false } = props;
   const reference = referenceForProvidedAPI(crd);
   const model = modelFor(reference);
   const createRoute = () =>
     `/k8s/ns/${csv.metadata.namespace}/${ClusterServiceVersionModel.plural}/${csv.metadata.name}/${reference}/~new`;
+
   return (
     <Card>
-      <CardHeader>
-        <ResourceLink
-          kind={referenceForProvidedAPI(crd)}
-          title={crd.name}
-          linkTo={false}
-          displayName={crd.displayName || crd.kind}
-        />
-      </CardHeader>
+      <CardTitle>
+        <span className="co-resource-item">
+          <ResourceLink
+            kind={referenceForProvidedAPI(crd)}
+            title={crd.name}
+            linkTo={false}
+            displayName={crd.displayName || crd.kind}
+          />
+          {required && (
+            <ResourceStatus badgeAlt>
+              <StatusIconAndText icon={<RedExclamationCircleIcon />} title="Required" />
+            </ResourceStatus>
+          )}
+        </span>
+      </CardTitle>
       <CardBody>
-        <p>{crd.description}</p>
+        <MarkdownView content={crd.description} truncateContent />
       </CardBody>
       {canCreate && (
         <RequireCreatePermission model={model} namespace={csv.metadata.namespace}>
@@ -761,6 +784,53 @@ export const CRDCardRow = connect(crdCardRowStateToProps)((props: CRDCardRowProp
   );
 });
 
+const InitializationResourceAlert: React.SFC<InitializationResourceAlertProps> = (props) => {
+  const { initializationResource, csv } = props;
+
+  const initializationResourceKind = initializationResource?.kind;
+  const { group: initializationResourceGroup } = groupVersionFor(
+    initializationResource?.apiVersion,
+  );
+  const model = modelFor(referenceFor(initializationResource));
+
+  // Check if the CR is already present - only checks for the specific name/ns in the initialization-resource
+  const [customResource, customResourceLoaded] = useK8sGet<K8sResourceCommon>(
+    model,
+    initializationResource?.metadata.name,
+    model?.namespaced ? initializationResource?.metadata.namespace || csv.metadata.namespace : null,
+  );
+  const canCreateCustomResource = useAccessReview({
+    group: initializationResourceGroup,
+    resource: model?.plural,
+    namespace: model?.namespaced
+      ? initializationResource?.metadata.namespace || csv.metadata.namespace
+      : null,
+    verb: 'create',
+  });
+
+  if (!customResource && customResourceLoaded && canCreateCustomResource) {
+    return (
+      <Alert
+        isInline
+        className="co-alert"
+        variant="warning"
+        title={`${initializationResourceKind} Required`}
+      >
+        <p>Create a {initializationResourceKind} instance to use this operator.</p>
+        <CreateInitializationResourceButton
+          obj={props.csv}
+          targetNamespace={
+            model?.namespaced
+              ? initializationResource?.metadata.namespace || csv.metadata?.namespace
+              : null
+          }
+        />
+      </Alert>
+    );
+  }
+  return null;
+};
+
 export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetailsProps> = (
   props,
 ) => {
@@ -768,8 +838,31 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
   const {
     'marketplace.openshift.io/support-workflow': marketplaceSupportWorkflow,
     'olm.targetNamespaces': olmTargetNamespaces = '',
+    'operatorframework.io/initialization-resource': initializationResourceJSON,
   } = metadata.annotations || {};
 
+  let initializationResource = null;
+  if (initializationResourceJSON) {
+    try {
+      initializationResource = JSON.parse(initializationResourceJSON);
+    } catch (error) {
+      // eslint-disable-next-line no-console
+      console.error(error.message);
+    }
+  }
+
+  let supportWorkflowUrl;
+  if (marketplaceSupportWorkflow) {
+    try {
+      const url = new URL(marketplaceSupportWorkflow);
+      url.searchParams.set('utm_source', 'openshift_console');
+      supportWorkflowUrl = url.toString();
+    } catch (error) {
+      // eslint-disable-next-line no-console
+      console.error(error.message);
+    }
+  }
+
   return (
     <>
       <ScrollToTopOnMount />
@@ -786,6 +879,12 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
                   title={`${status.phase}: ${status.message}`}
                 />
               )}
+              {initializationResource && (
+                <InitializationResourceAlert
+                  initializationResource={initializationResource}
+                  csv={props.obj}
+                />
+              )}
               <SectionHeading text="Provided APIs" />
               <CRDCardRow csv={props.obj} crdDescs={providedAPIsFor(props.obj)} />
               <SectionHeading text="Description" />
@@ -797,11 +896,11 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
                 <dd>
                   {spec.provider && spec.provider.name ? spec.provider.name : 'Not available'}
                 </dd>
-                {marketplaceSupportWorkflow && (
+                {supportWorkflowUrl && (
                   <>
                     <dt>Support</dt>
                     <dd>
-                      <ExternalLink href={marketplaceSupportWorkflow} text="Get support" />
+                      <ExternalLink href={supportWorkflowUrl} text="Get support" />
                     </dd>
                   </>
                 )}
@@ -858,7 +957,7 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
                     bodyContent={<div>Operands in this Namespace are managed by the Operator.</div>}
                     maxWidth="30rem"
                   >
-                    <Button variant="plain" className="co-m-pane__details-popover-button">
+                    <Button variant="plain" className="details-item__popover-button">
                       Managed Namespaces
                     </Button>
                   </Popover>
@@ -1034,7 +1133,7 @@ export const ClusterServiceVersionsDetailsPage: React.FC<ClusterServiceVersionsD
       breadcrumbsFor={() => [
         {
           name: 'Installed Operators',
-          path: `/k8s/ns/${props.match.params.ns}/${props.match.params.plural}`,
+          path: getBreadcrumbPath(props.match),
         },
         { name: 'Operator Details', path: props.match.url },
       ]}
@@ -1062,7 +1161,6 @@ export const ClusterServiceVersionsDetailsPage: React.FC<ClusterServiceVersionsD
 };
 
 type ClusterServiceVersionStatusProps = {
-  catalogSourceMissing: boolean;
   obj: ClusterServiceVersionKind;
   subscription: SubscriptionKind;
 };
@@ -1086,6 +1184,7 @@ export type CRDCardProps = {
   crd: CRDDescription | APIServiceDefinition;
   csv: ClusterServiceVersionKind;
   canCreate: boolean;
+  required?: boolean;
 };
 
 export type CRDCardRowProps = {
@@ -1150,6 +1249,11 @@ type ClusterServiceVersionStateProps = {
   activeNamespace?: string;
 };
 
+type InitializationResourceAlertProps = {
+  csv: ClusterServiceVersionKind;
+  initializationResource: K8sResourceCommon;
+};
+
 type Header = {
   title: string;
   sortField?: string;
